@@ -1,3 +1,4 @@
+import contextlib
 import getpass
 import logging
 import os
@@ -80,7 +81,7 @@ def clear_env(monkeypatch: pytest.MonkeyPatch) -> None:
 
     tmux show-environment tests were being interrupted due to a lot of crazy env vars.
     """
-    for k, v in os.environ.items():
+    for k in os.environ:
         if not any(
             needle in k.lower()
             for needle in [
@@ -133,8 +134,7 @@ def server(
 
         >>> result.assert_outcomes(passed=1)
     """
-    t = Server()
-    t.socket_name = "libtmux_test%s" % next(namer)
+    t = Server(socket_name="libtmux_test%s" % next(namer))
 
     def fin() -> None:
         t.kill_server()
@@ -145,7 +145,47 @@ def server(
 
 
 @pytest.fixture(scope="function")
-def session(request: pytest.FixtureRequest, server: Server) -> "Session":
+def session_params() -> t.Dict[str, t.Any]:
+    """Returns a new, temporary :class:`libtmux.Session`
+
+    >>> import pytest
+    >>> from libtmux.session import Session
+
+    >>> @pytest.fixture
+    ... def session_params(session_params):
+    ...     return {
+    ...         'x': 800,
+    ...         'y': 600,
+    ...     }
+
+    >>> def test_example(session: "Session") -> None:
+    ...     assert isinstance(session.name, str)
+    ...     assert session.name.startswith('libtmux_')
+    ...     window = session.new_window(window_name='new one')
+    ...     assert window.name == 'new one'
+
+    .. ::
+        >>> locals().keys()
+        dict_keys(...)
+
+        >>> source = ''.join([e.source for e in request._pyfuncitem.dtest.examples][:4])
+        >>> pytester = request.getfixturevalue('pytester')
+
+        >>> pytester.makepyfile(**{'whatever.py': source})
+        PosixPath(...)
+
+        >>> result = pytester.runpytest('whatever.py', '--disable-warnings')
+        ===...
+
+        >>> result.assert_outcomes(passed=1)
+    """
+    return {}
+
+
+@pytest.fixture(scope="function")
+def session(
+    request: pytest.FixtureRequest, session_params: t.Dict[str, t.Any], server: Server
+) -> "Session":
     """Returns a new, temporary :class:`libtmux.Session`
 
     >>> from libtmux.session import Session
@@ -178,35 +218,29 @@ def session(request: pytest.FixtureRequest, server: Server) -> "Session":
 
     # find current sessions prefixed with tmuxp
     old_test_sessions = []
-    for s in server._sessions:
-        old_name = s.get("session_name")
+    for s in server.sessions:
+        old_name = s.session_name
         if old_name is not None and old_name.startswith(TEST_SESSION_PREFIX):
             old_test_sessions.append(old_name)
 
     TEST_SESSION_NAME = get_test_session_name(server=server)
 
-    try:
-        session = server.new_session(session_name=TEST_SESSION_NAME)
-    except exc.LibTmuxException as e:
-        raise e
+    session = server.new_session(session_name=TEST_SESSION_NAME, **session_params)
 
     """
     Make sure that tmuxp can :ref:`test_builder_visually` and switches to
     the newly created session for that testcase.
     """
-    session_id = session.get("session_id")
+    session_id = session.session_id
     assert session_id is not None
 
-    try:
+    with contextlib.suppress(exc.LibTmuxException):
         server.switch_client(target_session=session_id)
-    except exc.LibTmuxException:
-        # server.attach_session(session.get('session_id'))
-        pass
 
     for old_test_session in old_test_sessions:
-        logger.debug("Old test test session %s found. Killing it." % old_test_session)
+        logger.debug(f"Old test test session {old_test_session} found. Killing it.")
         server.kill_session(old_test_session)
-    assert TEST_SESSION_NAME == session.get("session_name")
+    assert session.session_name == TEST_SESSION_NAME
     assert TEST_SESSION_NAME != "tmuxp"
 
     return session
