@@ -6,35 +6,46 @@ libtmux.server
 """
 import logging
 import os
+import pathlib
+import shutil
+import subprocess
 import typing as t
+import warnings
 
+from libtmux._internal.query_list import QueryList
 from libtmux.common import tmux_cmd
+from libtmux.neo import fetch_objs
+from libtmux.pane import Pane
 from libtmux.session import Session
+from libtmux.window import Window
 
 from . import exc, formats
 from .common import (
     EnvironmentMixin,
     PaneDict,
     SessionDict,
-    TmuxRelationalObject,
     WindowDict,
     has_gte_version,
     session_check_name,
 )
 
+if t.TYPE_CHECKING:
+    from typing_extensions import Literal, TypeAlias
+
+    DashLiteral: TypeAlias = Literal["-"]
+
 logger = logging.getLogger(__name__)
 
 
-class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
-
+class Server(EnvironmentMixin):
     """
     The :term:`tmux(1)` :term:`Server` [server_manual]_.
 
-    - :attr:`Server._sessions` [:class:`Session`, ...]
+    - :attr:`Server.sessions` [:class:`Session`, ...]
 
-      - :attr:`Session._windows` [:class:`Window`, ...]
+      - :attr:`Session.windows` [:class:`Window`, ...]
 
-        - :attr:`Window._panes` [:class:`Pane`, ...]
+        - :attr:`Window.panes` [:class:`Pane`, ...]
 
           - :class:`Pane`
 
@@ -50,7 +61,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
     Examples
     --------
     >>> server
-    <libtmux.server.Server object at ...>
+    Server(socket_name=libtmux_test...)
 
     >>> server.sessions
     [Session($1 ...)]
@@ -59,7 +70,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
     [Window(@1 1:..., Session($1 ...)]
 
     >>> server.sessions[0].attached_window
-    Window(@1 1:..., Session($1 ...)
+    Window(@1 1:..., Session($1 ...))
 
     >>> server.sessions[0].attached_pane
     Pane(%1 Window(@1 1:..., Session($1 ...)))
@@ -94,7 +105,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
     def __init__(
         self,
         socket_name: t.Optional[str] = None,
-        socket_path: t.Optional[str] = None,
+        socket_path: t.Optional[t.Union[str, pathlib.Path]] = None,
         config_file: t.Optional[str] = None,
         colors: t.Optional[int] = None,
         **kwargs: t.Any,
@@ -103,11 +114,20 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         self._windows: t.List[WindowDict] = []
         self._panes: t.List[PaneDict] = []
 
-        if socket_name:
+        if socket_path is not None:
+            self.socket_path = socket_path
+        elif socket_name is not None:
             self.socket_name = socket_name
 
-        if socket_path:
-            self.socket_path = socket_path
+        tmux_tmpdir = pathlib.Path(os.getenv("TMUX_TMPDIR", "/tmp"))
+        socket_name = self.socket_name or "default"
+        if (
+            tmux_tmpdir is not None
+            and self.socket_path is None
+            and self.socket_name is None
+            and socket_name != "default"
+        ):
+            self.socket_path = str(tmux_tmpdir / f"tmux-{os.geteuid()}" / socket_name)
 
         if config_file:
             self.config_file = config_file
@@ -115,10 +135,54 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         if colors:
             self.colors = colors
 
+    def is_alive(self) -> bool:
+        """If server alive or not.
+
+        >>> tmux = Server(socket_name="no_exist")
+        >>> assert not tmux.is_alive()
+        """
+        try:
+            res = self.cmd("list-sessions")
+        except Exception:
+            return False
+        return res.returncode == 0
+
+    def raise_if_dead(self) -> None:
+        """Raise if server not connected.
+
+        >>> tmux = Server(socket_name="no_exist")
+        >>> try:
+        ...     tmux.raise_if_dead()
+        ... except Exception as e:
+        ...     print(type(e))
+        <class 'subprocess.CalledProcessError'>
+        """
+        tmux_bin = shutil.which("tmux")
+        if tmux_bin is None:
+            raise exc.TmuxCommandNotFound()
+
+        cmd_args: t.List[str] = ["list-sessions"]
+        if self.socket_name:
+            cmd_args.insert(0, f"-L{self.socket_name}")
+        if self.socket_path:
+            cmd_args.insert(0, f"-S{self.socket_path}")
+        if self.config_file:
+            cmd_args.insert(0, f"-f{self.config_file}")
+
+        subprocess.check_call([tmux_bin, *cmd_args])
+
+    #
+    # Command
+    #
     def cmd(self, *args: t.Any, **kwargs: t.Any) -> tmux_cmd:
         """
         Execute tmux command and return output.
 
+        Examples
+        --------
+        >>> server.cmd('display-message', 'hi')
+        <libtmux.common.tmux_cmd object at ...>
+
         Returns
         -------
         :class:`common.tmux_cmd`
@@ -143,233 +207,40 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
             elif self.colors == 88:
                 cmd_args.insert(0, "-8")
             else:
-                raise ValueError("Server.colors must equal 88 or 256")
+                raise exc.UnknownColorOption()
 
         return tmux_cmd(*cmd_args, **kwargs)
 
-    def _list_sessions(self) -> t.List[SessionDict]:
-        """
-        Return list of sessions in :py:obj:`dict` form.
-
-        Retrieved from ``$ tmux(1) list-sessions`` stdout.
-
-        The :py:obj:`list` is derived from ``stdout`` in
-        :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
-
-        Returns
-        -------
-        list of dict
-        """
-
-        sformats = formats.SESSION_FORMATS
-        tmux_formats = ["#{%s}" % f for f in sformats]
-
-        tmux_args = ("-F%s" % formats.FORMAT_SEPARATOR.join(tmux_formats),)  # output
-
-        list_sessions_cmd = self.cmd("list-sessions", *tmux_args)
-
-        if list_sessions_cmd.stderr:
-            raise exc.LibTmuxException(list_sessions_cmd.stderr)
-
-        sformats = formats.SESSION_FORMATS
-        tmux_formats = ["#{%s}" % format for format in sformats]
-        sessions_output = list_sessions_cmd.stdout
-
-        # combine format keys with values returned from ``tmux list-sessions``
-        sessions_formatters = [
-            dict(zip(sformats, session.split(formats.FORMAT_SEPARATOR)))
-            for session in sessions_output
-        ]
-
-        # clear up empty dict
-        sessions_formatters_filtered = [
-            {k: v for k, v in session.items() if v} for session in sessions_formatters
-        ]
-
-        return sessions_formatters_filtered
-
     @property
-    def _sessions(self) -> t.List[SessionDict]:
-        """Property / alias to return :meth:`~._list_sessions`."""
-
-        return self._list_sessions()
-
-    def list_sessions(self) -> t.List[Session]:
-        """
-        Return list of :class:`Session` from the ``tmux(1)`` session.
-
-        Returns
-        -------
-        list of :class:`Session`
-        """
-        return [Session(server=self, **s) for s in self._sessions]
-
-    @property
-    def sessions(self) -> t.List[Session]:
-        """Property / alias to return :meth:`~.list_sessions`."""
-        return self.list_sessions()
-
-    #: Alias :attr:`sessions` for :class:`~libtmux.common.TmuxRelationalObject`
-    children = sessions  # type: ignore
-
-    def _list_windows(self) -> t.List[WindowDict]:
-        """
-        Return list of windows in :py:obj:`dict` form.
-
-        Retrieved from ``$ tmux(1) list-windows`` stdout.
-
-        The :py:obj:`list` is derived from ``stdout`` in
-        :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
-
-        Returns
-        -------
-        list of dict
-        """
-
-        wformats = ["session_name", "session_id"] + formats.WINDOW_FORMATS
-        tmux_formats = ["#{%s}" % format for format in wformats]
-
-        proc = self.cmd(
-            "list-windows",  # ``tmux list-windows``
-            "-a",
-            "-F%s" % formats.FORMAT_SEPARATOR.join(tmux_formats),  # output
-        )
-
-        if proc.stderr:
-            raise exc.LibTmuxException(proc.stderr)
-
-        window_output = proc.stdout
-
-        wformats = ["session_name", "session_id"] + formats.WINDOW_FORMATS
-
-        # combine format keys with values returned from ``tmux list-windows``
-        window_formatters = [
-            dict(zip(wformats, window.split(formats.FORMAT_SEPARATOR)))
-            for window in window_output
-        ]
-
-        # clear up empty dict
-        window_formatters_filtered = [
-            {k: v for k, v in window.items() if v} for window in window_formatters
-        ]
-
-        # tmux < 1.8 doesn't have window_id, use window_name
-        for w in window_formatters_filtered:
-            if "window_id" not in w:
-                w["window_id"] = w["window_name"]
-
-        if self._windows:
-            self._windows[:] = []
-
-        self._windows.extend(window_formatters_filtered)
-
-        return self._windows
-
-    def _update_windows(self) -> "Server":
-        """
-        Update internal window data and return ``self`` for chainability.
-
-        Returns
-        -------
-        :class:`Server`
-        """
-        self._list_windows()
-        return self
-
-    def _list_panes(self) -> t.List[PaneDict]:
-        """
-        Return list of panes in :py:obj:`dict` form.
-
-        Retrieved from ``$ tmux(1) list-panes`` stdout.
-
-        The :py:obj:`list` is derived from ``stdout`` in
-        :class:`util.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
-
-        Returns
-        -------
-        list
-        """
-
-        pformats = [
-            "session_name",
-            "session_id",
-            "window_index",
-            "window_id",
-            "window_name",
-        ] + formats.PANE_FORMATS
-        tmux_formats = [("#{%%s}%s" % formats.FORMAT_SEPARATOR) % f for f in pformats]
-
-        proc = self.cmd("list-panes", "-a", "-F%s" % "".join(tmux_formats))  # output
-
-        if proc.stderr:
-            raise exc.LibTmuxException(proc.stderr)
-
-        pane_output = proc.stdout
-
-        pformats = [
-            "session_name",
-            "session_id",
-            "window_index",
-            "window_id",
-            "window_name",
-        ] + formats.PANE_FORMATS
-
-        # combine format keys with values returned from ``tmux list-panes``
-        pane_formatters = [
-            dict(zip(pformats, formatter.split(formats.FORMAT_SEPARATOR)))
-            for formatter in pane_output
-        ]
-
-        # Filter empty values
-        pane_formatters_filtered = [
-            {
-                k: v for k, v in formatter.items() if v or k == "pane_current_path"
-            }  # preserve pane_current_path, in case it entered a new process
-            # where we may not get a cwd from.
-            for formatter in pane_formatters
-        ]
-
-        if self._panes:
-            self._panes[:] = []
-
-        self._panes.extend(pane_formatters_filtered)
-
-        return self._panes
-
-    def _update_panes(self) -> "Server":
-        """
-        Update internal pane data and return ``self`` for chainability.
-
-        Returns
-        -------
-        :class:`Server`
-        """
-        self._list_panes()
-        return self
-
-    @property
-    def attached_sessions(self) -> t.Optional[t.List[Session]]:
+    def attached_sessions(self) -> t.List[Session]:
         """
         Return active :class:`Session` objects.
 
+        Examples
+        --------
+        >>> server.attached_sessions
+        []
+
         Returns
         -------
         list of :class:`Session`
         """
+        try:
+            sessions = self.sessions
+            attached_sessions = []
 
-        sessions = self._sessions
-        attached_sessions = list()
+            for session in sessions:
+                attached = session.session_attached
+                # for now session_active is a unicode
+                if attached != "0":
+                    logger.debug(f"session {session.name} attached")
+                    attached_sessions.append(session)
+                else:
+                    continue
 
-        for session in sessions:
-            attached = session.get("session_attached")
-            # for now session_active is a unicode
-            if attached != "0":
-                logger.debug("session %s attached", session.get("name"))
-                attached_sessions.append(session)
-            else:
-                continue
-
-        return [Session(server=self, **s) for s in attached_sessions] or None
+        except Exception:
+            return []
+        return attached_sessions
 
     def has_session(self, target_session: str, exact: bool = True) -> bool:
         """
@@ -467,7 +338,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         """
         session_check_name(target_session)
 
-        tmux_args: t.Tuple[str, ...] = tuple()
+        tmux_args: t.Tuple[str, ...] = ()
         if target_session:
             tmux_args += ("-t%s" % target_session,)
 
@@ -484,6 +355,8 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         start_directory: t.Optional[str] = None,
         window_name: t.Optional[str] = None,
         window_command: t.Optional[str] = None,
+        x: t.Optional[t.Union[int, "DashLiteral"]] = None,
+        y: t.Optional[t.Union[int, "DashLiteral"]] = None,
         *args: t.Any,
         **kwargs: t.Any,
     ) -> Session:
@@ -521,11 +394,17 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
             ::
 
                 $ tmux new-session -n <window_name>
-        window_command : str
+        window_command : str, optional
             execute a command on starting the session.  The window will close
             when the command exits. NOTE: When this command exits the window
             will close.  This feature is useful for long-running processes
             where the closing of the window upon completion is desired.
+        x : [int, str], optional
+            Force the specified width instead of the tmux default for a
+            dettached session
+        y : [int, str], optional
+            Force the specified height instead of the tmux default for a
+            dettached session
 
         Returns
         -------
@@ -564,10 +443,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
                         "Session named %s exists" % session_name
                     )
 
-        logger.debug("creating session %s" % session_name)
-
-        sformats = formats.SESSION_FORMATS
-        tmux_formats = ["#{%s}" % f for f in sformats]
+        logger.debug(f"creating session {session_name}")
 
         env = os.environ.get("TMUX")
 
@@ -576,7 +452,7 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
 
         tmux_args: t.Tuple[t.Union[str, int], ...] = (
             "-P",
-            "-F%s" % formats.FORMAT_SEPARATOR.join(tmux_formats),  # output
+            "-F#{session_id}",  # output
         )
 
         if session_name is not None:
@@ -591,10 +467,11 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         if window_name:
             tmux_args += ("-n", window_name)
 
-        # tmux 2.6 gives unattached sessions a tiny default area
-        # no need send in -x/-y if they're in a client already, though
-        if has_gte_version("2.6") and "TMUX" not in os.environ:
-            tmux_args += ("-x", 800, "-y", 600)
+        if x is not None:
+            tmux_args += ("-x", x)
+
+        if y is not None:
+            tmux_args += ("-y", y)
 
         if window_command:
             tmux_args += (window_command,)
@@ -609,14 +486,206 @@ class Server(TmuxRelationalObject["Session", "SessionDict"], EnvironmentMixin):
         if env:
             os.environ["TMUX"] = env
 
-        # Combine format keys with values returned from ``tmux list-windows``
-        session_params = dict(
-            zip(sformats, session_stdout.split(formats.FORMAT_SEPARATOR))
+        session_formatters = dict(
+            zip(["session_id"], session_stdout.split(formats.FORMAT_SEPARATOR))
         )
 
-        # Filter empty values
-        session_params = {k: v for k, v in session_params.items() if v}
+        return Session.from_session_id(
+            server=self, session_id=session_formatters["session_id"]
+        )
 
-        session = Session(server=self, **session_params)
+    #
+    # Relations
+    #
+    @property
+    def sessions(self) -> QueryList[Session]:  # type:ignore
+        """Sessions belonging server.
 
-        return session
+        Can be accessed via
+        :meth:`.sessions.get() <libtmux._internal.query_list.QueryList.get()>` and
+        :meth:`.sessions.filter() <libtmux._internal.query_list.QueryList.filter()>`
+        """
+        sessions: t.List["Session"] = []
+
+        try:
+            for obj in fetch_objs(
+                list_cmd="list-sessions",
+                server=self,
+            ):
+                sessions.append(Session(server=self, **obj))  # noqa: PERF401
+        except Exception:
+            pass
+
+        return QueryList(sessions)
+
+    @property
+    def windows(self) -> QueryList[Window]:  # type:ignore
+        """Windows belonging server.
+
+        Can be accessed via
+        :meth:`.windows.get() <libtmux._internal.query_list.QueryList.get()>` and
+        :meth:`.windows.filter() <libtmux._internal.query_list.QueryList.filter()>`
+        """
+        windows: t.List["Window"] = [
+            Window(server=self, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-windows",
+                list_extra_args=("-a",),
+                server=self,
+            )
+        ]
+
+        return QueryList(windows)
+
+    @property
+    def panes(self) -> QueryList[Pane]:  # type:ignore
+        """Panes belonging server.
+
+        Can be accessed via
+        :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
+        :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
+        """
+        panes: t.List["Pane"] = [
+            Pane(server=self, **obj)
+            for obj in fetch_objs(
+                list_cmd="list-panes",
+                list_extra_args=["-s"],
+                server=self,
+            )
+        ]
+
+        return QueryList(panes)
+
+    #
+    # Dunder
+    #
+    def __eq__(self, other: object) -> bool:
+        assert isinstance(other, Server)
+        return (
+            self.socket_name == other.socket_name
+            and self.socket_path == other.socket_path
+        )
+
+    def __repr__(self) -> str:
+        if self.socket_name is not None:
+            return (
+                f"{self.__class__.__name__}"
+                f"(socket_name={getattr(self, 'socket_name', 'default')})"
+            )
+        elif self.socket_path is not None:
+            return f"{self.__class__.__name__}" f"(socket_path={self.socket_path})"
+        return f"{self.__class__.__name__}" f"(socket_path=/tmp/tmux-1000/default)"
+
+    #
+    # Legacy: Redundant stuff we want to remove
+    #
+    def _list_panes(self) -> t.List[PaneDict]:
+        """
+        Return list of panes in :py:obj:`dict` form.
+
+        Retrieved from ``$ tmux(1) list-panes`` stdout.
+
+        The :py:obj:`list` is derived from ``stdout`` in
+        :class:`util.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._list_panes() is deprecated", stacklevel=2)
+        return [p.__dict__ for p in self.panes]
+
+    def _update_panes(self) -> "Server":
+        """
+        Update internal pane data and return ``self`` for chainability.
+
+        Returns
+        -------
+        :class:`Server`
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._update_panes() is deprecated", stacklevel=2)
+        self._list_panes()
+        return self
+
+    def get_by_id(self, id: str) -> t.Optional[Session]:
+        """
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server.get_by_id() is deprecated", stacklevel=2)
+        return self.sessions.get(session_id=id, default=None)
+
+    def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Session]:
+        """
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
+        try:
+            return self.sessions.filter(**kwargs)
+        except IndexError:
+            return []
+
+    def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Session]:
+        """
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server.find_where() is deprecated", stacklevel=2)
+        return self.sessions.get(default=None, **kwargs)
+
+    def _list_windows(self) -> t.List[WindowDict]:
+        """Return list of windows in :py:obj:`dict` form.
+
+        Retrieved from ``$ tmux(1) list-windows`` stdout.
+
+        The :py:obj:`list` is derived from ``stdout`` in
+        :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._list_windows() is deprecated", stacklevel=2)
+        return [w.__dict__ for w in self.windows]
+
+    def _update_windows(self) -> "Server":
+        """Update internal window data and return ``self`` for chainability.
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._update_windows() is deprecated", stacklevel=2)
+        self._list_windows()
+        return self
+
+    @property
+    def _sessions(self) -> t.List[SessionDict]:
+        """Property / alias to return :meth:`~._list_sessions`.
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._sessions is deprecated", stacklevel=2)
+        return self._list_sessions()
+
+    def _list_sessions(self) -> t.List["SessionDict"]:
+        """
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server._list_sessions() is deprecated", stacklevel=2)
+        return [s.__dict__ for s in self.sessions]
+
+    def list_sessions(self) -> t.List[Session]:
+        """Return list of :class:`Session` from the ``tmux(1)`` session.
+
+        .. deprecated:: 0.16
+
+        Returns
+        -------
+        list of :class:`Session`
+        """
+        warnings.warn("Server.list_sessions is deprecated", stacklevel=2)
+        return self.sessions
+
+    @property
+    def children(self) -> QueryList["Session"]:  # type:ignore
+        """Was used by TmuxRelationalObject (but that's longer used in this class)
+
+        .. deprecated:: 0.16
+        """
+        warnings.warn("Server.children is deprecated", stacklevel=2)
+        return self.sessions
